#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ech-config
version:              0.0.1
visibility:           public
id:                   ech-config-0.0.1-CKQj88XnPN49eVuSADbwKU
key:                  ech-config-0.0.1-CKQj88XnPN49eVuSADbwKU
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
synopsis:             Config for TLS Encrypted Client Hello
description:
    Config types for TLS Encrypted Client Hello to glue DNS and TLS

category:             Network
abi:                  5b1fbc56dc50b6bae2c3da5e0c543668
exposed:              True
exposed-modules:      Network.TLS.ECH.Config
import-dirs:          /usr/lib/ghc-9.6.6/site-local/ech-config-0.0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ech-config-0.0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ech-config-0.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ech-config
hs-libraries:         HSech-config-0.0.1-CKQj88XnPN49eVuSADbwKU
depends:
    base-4.18.2.1 base16-bytestring-1.0.2.0-KkKTvweYtUjAEl7m2QLWFY
    bytestring-0.11.5.3 filepath-1.4.300.1
    network-byte-order-0.1.7-KOrHLkTNWo52qSQao8kAgk

haddock-interfaces:   /usr/share/doc/haskell-ech-config/html/ech-config.haddock
haddock-html:         /usr/share/doc/haskell-ech-config/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

